@@ -1,4 +1,4 @@
 library(testthat)
 library(nlmixr2extra)
 
-test_check("nlmixr2extra")
+#test_check("nlmixr2extra")
